==> client-java-api-4.0.0-sources.jar: io/kubernetes/client/models/V2beta1PodsMetricSourceFluent.java <==
package io.kubernetes.client.models;

import java.lang.Deprecated;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.Boolean;

public interface V2beta1PodsMetricSourceFluent<A extends V2beta1PodsMetricSourceFluent<A>> extends Fluent<A>{


    public String getMetricName();
    public A withMetricName(String metricName);
    public Boolean hasMetricName();
    
/**
 * This method has been deprecated, please use method buildSelector instead.
 * @return The buildable object.
 */
@Deprecated public V1LabelSelector getSelector();
    public V1LabelSelector buildSelector();
    public A withSelector(V1LabelSelector selector);
    public Boolean hasSelector();
    public V2beta1PodsMetricSourceFluent.SelectorNested<A> withNewSelector();
    public V2beta1PodsMetricSourceFluent.SelectorNested<A> withNewSelectorLike(V1LabelSelector item);
    public V2beta1PodsMetricSourceFluent.SelectorNested<A> editSelector();
    public V2beta1PodsMetricSourceFluent.SelectorNested<A> editOrNewSelector();
    public V2beta1PodsMetricSourceFluent.SelectorNested<A> editOrNewSelectorLike(V1LabelSelector item);
    public String getTargetAverageValue();
    public A withTargetAverageValue(String targetAverageValue);
    public Boolean hasTargetAverageValue();

    public interface SelectorNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1LabelSelectorFluent<V2beta1PodsMetricSourceFluent.SelectorNested<N>>{

        
    public N and();    public N endSelector();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V2beta1PodsMetricSourceFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Boolean;

public interface V2beta1PodsMetricSourceFluent<A extends V2beta1PodsMetricSourceFluent<A>> extends Fluent<A>{


    public String getMetricName();
    public A withMetricName(String metricName);
    public Boolean hasMetricName();
    public A withNewMetricName(String arg1);
    public A withNewMetricName(StringBuilder arg1);
    public A withNewMetricName(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildSelector instead.
 * @return The buildable object.
 */
@Deprecated public V1LabelSelector getSelector();
    public V1LabelSelector buildSelector();
    public A withSelector(V1LabelSelector selector);
    public Boolean hasSelector();
    public V2beta1PodsMetricSourceFluent.SelectorNested<A> withNewSelector();
    public V2beta1PodsMetricSourceFluent.SelectorNested<A> withNewSelectorLike(V1LabelSelector item);
    public V2beta1PodsMetricSourceFluent.SelectorNested<A> editSelector();
    public V2beta1PodsMetricSourceFluent.SelectorNested<A> editOrNewSelector();
    public V2beta1PodsMetricSourceFluent.SelectorNested<A> editOrNewSelectorLike(V1LabelSelector item);
    public String getTargetAverageValue();
    public A withTargetAverageValue(String targetAverageValue);
    public Boolean hasTargetAverageValue();
    public A withNewTargetAverageValue(String arg1);
    public A withNewTargetAverageValue(StringBuilder arg1);
    public A withNewTargetAverageValue(StringBuffer arg1);

    public interface SelectorNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1LabelSelectorFluent<V2beta1PodsMetricSourceFluent.SelectorNested<N>>{

        
    public N and();    public N endSelector();
}


}
